==> grpc-netty-0.13.1-sources.jar: io/grpc/netty/SendResponseHeadersCommand.java <==
/*
 * Copyright 2014, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *
 *    * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package io.grpc.netty;

import com.google.common.base.Preconditions;

import io.netty.handler.codec.http2.Http2Headers;

/**
 * Command sent from the transport to the Netty channel to send response headers to the client.
 */
class SendResponseHeadersCommand {
  private final int streamId;
  private final Http2Headers headers;
  private final boolean endOfStream;

  SendResponseHeadersCommand(int streamId, Http2Headers headers, boolean endOfStream) {
    this.streamId = streamId;
    this.headers = Preconditions.checkNotNull(headers);
    this.endOfStream = endOfStream;
  }

  int streamId() {
    return streamId;
  }

  Http2Headers headers() {
    return headers;
  }

  boolean endOfStream() {
    return endOfStream;
  }

  @Override
  public boolean equals(Object that) {
    if (that == null || !that.getClass().equals(SendResponseHeadersCommand.class)) {
      return false;
    }
    SendResponseHeadersCommand thatCmd = (SendResponseHeadersCommand) that;
    return thatCmd.streamId == streamId
        && thatCmd.headers.equals(headers)
        && thatCmd.endOfStream == endOfStream;
  }

  @Override
  public String toString() {
    return getClass().getSimpleName() + "(streamId=" + streamId + ", headers=" + headers
        + ", endOfStream=" + endOfStream + ")";
  }

  @Override
  public int hashCode() {
    return streamId;
  }
}

==> grpc-netty-1.0.0-pre1-sources.jar: io/grpc/netty/SendResponseHeadersCommand.java <==
/*
 * Copyright 2014, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *
 *    * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package io.grpc.netty;

import com.google.common.base.Preconditions;

import io.netty.handler.codec.http2.Http2Headers;

/**
 * Command sent from the transport to the Netty channel to send response headers to the client.
 */
class SendResponseHeadersCommand extends WriteQueue.AbstractQueuedCommand {
  private final StreamIdHolder stream;
  private final Http2Headers headers;
  private final boolean endOfStream;

  SendResponseHeadersCommand(StreamIdHolder stream, Http2Headers headers, boolean endOfStream) {
    this.stream = Preconditions.checkNotNull(stream);
    this.headers = Preconditions.checkNotNull(headers);
    this.endOfStream = endOfStream;
  }

  StreamIdHolder stream() {
    return stream;
  }

  Http2Headers headers() {
    return headers;
  }

  boolean endOfStream() {
    return endOfStream;
  }

  @Override
  public boolean equals(Object that) {
    if (that == null || !that.getClass().equals(SendResponseHeadersCommand.class)) {
      return false;
    }
    SendResponseHeadersCommand thatCmd = (SendResponseHeadersCommand) that;
    return thatCmd.stream.equals(stream)
        && thatCmd.headers.equals(headers)
        && thatCmd.endOfStream == endOfStream;
  }

  @Override
  public String toString() {
    return getClass().getSimpleName() + "(stream=" + stream.id() + ", headers=" + headers
        + ", endOfStream=" + endOfStream + ")";
  }

  @Override
  public int hashCode() {
    return stream.hashCode();
  }
}
